# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class MongoSourceFieldsConfig(UniversalBaseModel):
    body: str
    source_name: typing_extensions.Annotated[str, FieldMetadata(alias="sourceName")]
    source_system_updated: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="sourceSystemUpdated")
    ] = None
    source_url: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="sourceUrl")] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
