# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        AiEndpointConfiguration,
        BlockedChunk,
        BooleanFieldSchema,
        CollectionFilteredData,
        Configuration,
        CreateConversationResponse,
        CreateCopilotResponse,
        DataChunk,
        DataFilter,
        DatetimeFieldSchema,
        DeleteCopilotResponse,
        EndOfMessageChunk,
        ErrorChunk,
        ErrorChunkData,
        ExportCopilotsResponse,
        ExportedCopilot,
        FeedbackEnum,
        Filter,
        Filter_Boolean,
        Filter_Datetime,
        Filter_Number,
        Filter_String,
        FinalChunk,
        InitialChunk,
        InputVariable,
        InsertedAuditLog,
        MessageBlocked,
        MessageFeedback,
        MessageReply,
        NumberFieldSchema,
        ReferencedSource,
        ResponseChunk,
        SendAgentMessageResponse,
        SendMessageResponse,
        SendMessageResponse_AiResponseResult,
        SendMessageResponse_BlockedResult,
        StreamingChunk,
        StreamingChunk_Blocked,
        StreamingChunk_DataChunk,
        StreamingChunk_EndOfMessage,
        StreamingChunk_ErrorChunk,
        StreamingChunk_FinalChunk,
        StreamingChunk_Initial,
        StringFieldSchema,
        WebSearchResult,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "AiEndpointConfiguration": ".types",
    "BlockedChunk": ".types",
    "BooleanFieldSchema": ".types",
    "CollectionFilteredData": ".types",
    "Configuration": ".types",
    "CreateConversationResponse": ".types",
    "CreateCopilotResponse": ".types",
    "DataChunk": ".types",
    "DataFilter": ".types",
    "DatetimeFieldSchema": ".types",
    "DeleteCopilotResponse": ".types",
    "EndOfMessageChunk": ".types",
    "ErrorChunk": ".types",
    "ErrorChunkData": ".types",
    "ExportCopilotsResponse": ".types",
    "ExportedCopilot": ".types",
    "FeedbackEnum": ".types",
    "Filter": ".types",
    "Filter_Boolean": ".types",
    "Filter_Datetime": ".types",
    "Filter_Number": ".types",
    "Filter_String": ".types",
    "FinalChunk": ".types",
    "InitialChunk": ".types",
    "InputVariable": ".types",
    "InsertedAuditLog": ".types",
    "MessageBlocked": ".types",
    "MessageFeedback": ".types",
    "MessageReply": ".types",
    "NumberFieldSchema": ".types",
    "ReferencedSource": ".types",
    "ResponseChunk": ".types",
    "SendAgentMessageResponse": ".types",
    "SendMessageResponse": ".types",
    "SendMessageResponse_AiResponseResult": ".types",
    "SendMessageResponse_BlockedResult": ".types",
    "StreamingChunk": ".types",
    "StreamingChunk_Blocked": ".types",
    "StreamingChunk_DataChunk": ".types",
    "StreamingChunk_EndOfMessage": ".types",
    "StreamingChunk_ErrorChunk": ".types",
    "StreamingChunk_FinalChunk": ".types",
    "StreamingChunk_Initial": ".types",
    "StringFieldSchema": ".types",
    "WebSearchResult": ".types",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AiEndpointConfiguration",
    "BlockedChunk",
    "BooleanFieldSchema",
    "CollectionFilteredData",
    "Configuration",
    "CreateConversationResponse",
    "CreateCopilotResponse",
    "DataChunk",
    "DataFilter",
    "DatetimeFieldSchema",
    "DeleteCopilotResponse",
    "EndOfMessageChunk",
    "ErrorChunk",
    "ErrorChunkData",
    "ExportCopilotsResponse",
    "ExportedCopilot",
    "FeedbackEnum",
    "Filter",
    "Filter_Boolean",
    "Filter_Datetime",
    "Filter_Number",
    "Filter_String",
    "FinalChunk",
    "InitialChunk",
    "InputVariable",
    "InsertedAuditLog",
    "MessageBlocked",
    "MessageFeedback",
    "MessageReply",
    "NumberFieldSchema",
    "ReferencedSource",
    "ResponseChunk",
    "SendAgentMessageResponse",
    "SendMessageResponse",
    "SendMessageResponse_AiResponseResult",
    "SendMessageResponse_BlockedResult",
    "StreamingChunk",
    "StreamingChunk_Blocked",
    "StreamingChunk_DataChunk",
    "StreamingChunk_EndOfMessage",
    "StreamingChunk_ErrorChunk",
    "StreamingChunk_FinalChunk",
    "StreamingChunk_Initial",
    "StringFieldSchema",
    "WebSearchResult",
]
